@@ -1,7 +1,7 @@
+use handlebars::Handlebars;
 use rocket::fs::{FileServer, Options as FSOptions};
 use rocket::response::Redirect;
 use rocket::{get, routes, Build, Rocket};
-use rocket_dyn_templates::Template;
 use std::sync::Arc;
 
 mod config;
@@ -25,13 +25,13 @@ fn rocket() -> anyhow::Result<Rocket<Build>> {
 
 	let rocket = rocket
 		.manage(config.clone())
-		.attach(Template::try_custom(|rocket_dyn_templates::Engines { handlebars: hbs, .. }| {
-			hbs.clear_templates(); // don't discover other templates
+		.manage({
+			let mut hbs = Handlebars::new();
 			hbs.set_strict_mode(true);
 			hbs.register_template_string("base", std::include_str!("../templates/base.hbs"))?;
-			hbs.register_template_string("index", std::include_str!("../templates/index.html.hbs"))?;
-			Ok(())
-		}))
+			hbs.register_template_string("index.html", std::include_str!("../templates/index.html.hbs"))?;
+			hbs
+		})
 		.mount("/static", routes![static_files::css, static_files::js])
 		.mount(
 			"/fs",
