@@ -13,8 +13,8 @@ pub fn css() -> TypedByteSlice<'static> {
 #[get("/js/index.js")]
 pub fn js() -> TypedByteSlice<'static> {
 	TypedByteSlice {
-		ty: ContentType::CSS,
-		data: std::include_bytes!("../static/index.css").as_slice(),
+		ty: ContentType::JavaScript,
+		data: include_bytes!("../static/index.js").as_slice(),
 	}
 }
 
