@@ -1,3 +1,4 @@
+use handlebars as hbs;
 use image as im;
 use rocket::http::Status;
 use std::path::Path;
@@ -40,6 +41,11 @@ pub fn stream_error_to_status(err: vi::StreamError) -> Status {
 	}
 }
 
+pub fn handlebars_error_to_status(err: hbs::RenderError) -> Status {
+	log::error!("Handlebars render error: {:?}", err);
+	Status::InternalServerError
+}
+
 pub fn get_file_mime(path: &Path) -> io::Result<Option<mime::Mime>> {
 	use mime_sniffer::MimeTypeSnifferExt;
 	let file = fs::File::open(path)?;
